"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = __importDefault(require("node-fetch"));
const cheerio_1 = __importDefault(require("cheerio"));
const turndown_1 = __importDefault(require("turndown"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const turndownService = new turndown_1.default();
const generate = (url, output) => __awaiter(this, void 0, void 0, function* () {
    output = path_1.default.resolve(output);
    try {
        fs_1.default.accessSync(output, fs_1.default.constants.W_OK);
    }
    catch (err) {
        // 不存在
        console.log("输出目录不存在，正在创建...");
        fs_1.default.mkdirSync(output);
    }
    const res = yield node_fetch_1.default(url);
    const html = yield res.text();
    const $ = cheerio_1.default.load(html);
    const htmlcontent = $(".markdown_views").html();
    const markdown = turndownService.turndown(htmlcontent || "");
    const time = $(".time")
        .text()
        .replace(/([\u4e00-\u9fa5])/g, "-")
        .replace(/\-\s/, " "); //时间格式化
    const title = $(".title-article").text();
    const tags = []; //标签
    const categories = []; //分类
    $(".tag-link").each(function () {
        const content = $(this)
            .text()
            .replace(/\t/g, "");
        if (/^(https|http):\/\/so.csdn.net\/so\/search\//.test($(this).attr("href"))) {
            // 标签
            tags.push(content);
        }
        else {
            categories.push(content);
        }
    });
    const writeStream = fs_1.default.createWriteStream(path_1.default.join(output, `./${title}.md`), "utf8");
    writeStream.write("---\n");
    writeStream.write(`title: ${title}\n`);
    writeStream.write(`date: ${time}\n`);
    writeStream.write(`tags: ${tags.join(" ")}\n`);
    writeStream.write(`categories: ${categories.join(" ")}\n`);
    writeStream.write("---\n\n");
    writeStream.write("<!--more-->\n\n");
    writeStream.write(markdown);
    writeStream.end("");
});
exports.default = generate;
//# sourceMappingURL=generate.js.map